@@ -17,6 +17,8 @@ var encoder_8h =
     [ "AV1EncRowMultiThreadInfo", "structAV1EncRowMultiThreadInfo.html", "structAV1EncRowMultiThreadInfo" ],
     [ "AV1EncAllIntraMultiThreadInfo", "structAV1EncAllIntraMultiThreadInfo.html", "structAV1EncAllIntraMultiThreadInfo" ],
     [ "RestoreStateBuffers", "structRestoreStateBuffers.html", "structRestoreStateBuffers" ],
+    [ "RestUnitSearchInfo", "structRestUnitSearchInfo.html", "structRestUnitSearchInfo" ],
+    [ "AV1LrPickStruct", "structAV1LrPickStruct.html", "structAV1LrPickStruct" ],
     [ "PrimaryMultiThreadInfo", "structPrimaryMultiThreadInfo.html", "structPrimaryMultiThreadInfo" ],
     [ "MultiThreadInfo", "structMultiThreadInfo.html", "structMultiThreadInfo" ],
     [ "ForceIntegerMVInfo", "structForceIntegerMVInfo.html", "structForceIntegerMVInfo" ],
