@@ -40,19 +40,7 @@ var NAVTREE =
     ] ],
     [ "CHANGELOG", "changelog.html", null ],
     [ "README.md", "readme.html", null ],
-    [ "Usage", "usage.html", [
-      [ "Important Data Types", "usage.html#usage_types", [
-        [ "Contexts", "usage.html#usage_ctxs", null ],
-        [ "Interfaces", "usage.html#usage_ifaces", null ]
-      ] ],
-      [ "Features", "usage.html#usage_features", null ],
-      [ "Initialization", "usage.html#usage_init", null ],
-      [ "Error Handling", "usage.html#usage_errors", null ],
-      [ "Decoding", "usage_decode.html", [
-        [ "Frame Iterator Based Decoding", "usage_decode.html#usage_frame_iter", null ]
-      ] ],
-      [ "Encoding", "usage_encode.html", null ]
-    ] ],
+    [ "Usage", "usage.html", "usage" ],
     [ "AV1 DECODER GUIDE", "decoder_guide.html", null ],
     [ "AV1 ENCODER GUIDE", "encoder_guide.html", [
       [ "Introduction", "encoder_guide.html#architecture_introduction", [
@@ -116,24 +104,7 @@ var NAVTREE =
         ] ]
       ] ]
     ] ],
-    [ "Sample Code", "samples.html", [
-      [ "decode_to_md5", "example_decode_to_md5.html", null ],
-      [ "decode_with_drops", "example_decode_with_drops.html", null ],
-      [ "simple_decoder", "example_simple_decoder.html", null ],
-      [ "lossless_encoder", "example_lossless_encoder.html", null ],
-      [ "set_maps", "example_set_maps.html", null ],
-      [ "simple_encoder", "example_simple_encoder.html", null ],
-      [ "twopass_encoder", "example_twopass_encoder.html", null ],
-      [ "scalable_encoder", "example_scalable_encoder.html", null ],
-      [ "svc_encoder_rtc", "example_svc_encoder_rtc.html", null ],
-      [ "aom_cx_set_ref", "example_aom_cx_set_ref.html", null ],
-      [ "lightfield_encoder", "example_lightfield_encoder.html", null ],
-      [ "lightfield_tile_list_decoder", "example_lightfield_tile_list_decoder.html", null ],
-      [ "lightfield_decoder", "example_lightfield_decoder.html", null ],
-      [ "lightfield_bitstream_parsing", "example_lightfield_bitstream_parsing.html", null ],
-      [ "aomdec", "example_aomdec.html", null ],
-      [ "aomenc", "example_aomenc.html", null ]
-    ] ],
+    [ "Sample Code", "samples.html", "samples" ],
     [ "README.md", "LREADME.html", [
       [ "AV1 Codec Library", "LREADME.html#autotoc_md0", [
         [ "Contents", "LREADME.html#autotoc_md1", null ],
@@ -154,17 +125,17 @@ var NAVTREE =
         ] ],
         [ "Testing the AV1 codec", "LREADME.html#testing-the-av1-codec", [
           [ "Testing basics", "LREADME.html#testing-basics", [
-            [ "1. Unit tests:", "LREADME.html#unit-tests", null ],
-            [ "2. Example tests:", "LREADME.html#example-tests", null ],
-            [ "3. Encoder tests:", "LREADME.html#encoder-tests", null ]
+            [ "Unit tests:", "LREADME.html#unit-tests", null ],
+            [ "Example tests:", "LREADME.html#example-tests", null ],
+            [ "Encoder tests:", "LREADME.html#encoder-tests", null ]
           ] ],
           [ "IDE hosted tests", "LREADME.html#ide-hosted-tests", null ],
           [ "Downloading the test data", "LREADME.html#downloading-the-test-data", null ],
           [ "Adding a new test data file", "LREADME.html#adding-a-new-test-data-file", null ],
           [ "Additional test data", "LREADME.html#additional-test-data", null ],
           [ "Sharded testing", "LREADME.html#sharded-testing", [
-            [ "1. Running test_libaom directly:", "LREADME.html#running-test_libaom-directly", null ],
-            [ "2. Running the tests via the CMake build:", "LREADME.html#running-the-tests-via-the-cmake-build", null ]
+            [ "Running test_libaom directly:", "LREADME.html#running-test_libaom-directly", null ],
+            [ "Running the tests via the CMake build:", "LREADME.html#running-the-tests-via-the-cmake-build", null ]
           ] ]
         ] ],
         [ "Coding style", "LREADME.html#coding-style", null ],
@@ -213,12 +184,12 @@ var NAVTREEINDEX =
 "group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38",
 "group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca413c6090fa855359106e32fbd2b5f668",
 "group__tpl__modelling.html#ga3d123b0f3781dcb06c5f4d053ac3655b",
-"structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f",
-"structCommonQuantParams.html#ae6b10a492cbf8dd0501129c7d264ee6d",
-"structMB__MODE__INFO.html#a13f1a883e73c4b721c2212d0416b3967",
-"structRestorationInfo.html#a6b8daa3388a9cacec495eb2d8ab88436",
-"structaom__codec__enc__cfg.html#ae55d1533084ea0090588dc1187baffb5",
-"structinter__modes__info.html#afa119f92044ae1a737bab446bade8c88"
+"structAV1__COMP.html#a79be536fcf6a3d04be9c6c7a838e2421",
+"structCommonQuantParams.html#aaeafbb83ee5df9c8fbba96f3cd250338",
+"structMB__MODE__INFO.html",
+"structRestUnitSearchInfo.html#af5f8afe160f8069bab2f1d3b917a0798",
+"structaom__codec__enc__cfg.html#ad5c6f5c96ec54cabc71edb01045a1f04",
+"structinter__modes__info.html#a8d48bef2f7a01707d70e05ef9819a7df"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
