@@ -1,5 +1,8 @@
 var NAVTREEINDEX6 =
 {
+"structCommonQuantParams.html#aaeafbb83ee5df9c8fbba96f3cd250338":[13,0,58,13],
+"structCommonQuantParams.html#ad5a34dbb0ead83ec6d2ef1a598ed832d":[13,0,58,6],
+"structCommonQuantParams.html#ade3a29210ea7504fcba1c4bcacd1e692":[13,0,58,3],
 "structCommonQuantParams.html#ae6b10a492cbf8dd0501129c7d264ee6d":[13,0,58,1],
 "structCommonQuantParams.html#afae3f12fc3aa940840f9a04b05fdd387":[13,0,58,10],
 "structCommonTileParams.html":[13,0,59],
@@ -246,8 +249,5 @@ var NAVTREEINDEX6 =
 "structMBMIExtFrameBufferInfo.html":[13,0,100],
 "structMBMIExtFrameBufferInfo.html#a4f34405dd12aa6f0fe1415c4f08b7823":[13,0,100,1],
 "structMBMIExtFrameBufferInfo.html#a774a8b281d7f026cbb5fd5889062d2c5":[13,0,100,2],
-"structMBMIExtFrameBufferInfo.html#aa3e1931e2edbe5ee3460688502a4dad6":[13,0,100,0],
-"structMB__MODE__INFO.html":[13,0,95],
-"structMB__MODE__INFO.html#a02b7e164e73fcad61b9167033cecd63d":[13,0,95,23],
-"structMB__MODE__INFO.html#a05cda5be151da599d4257c4fc9db9a46":[13,0,95,7]
+"structMBMIExtFrameBufferInfo.html#aa3e1931e2edbe5ee3460688502a4dad6":[13,0,100,0]
 };
