@@ -1,5 +1,8 @@
 var NAVTREEINDEX7 =
 {
+"structMB__MODE__INFO.html":[13,0,95],
+"structMB__MODE__INFO.html#a02b7e164e73fcad61b9167033cecd63d":[13,0,95,23],
+"structMB__MODE__INFO.html#a05cda5be151da599d4257c4fc9db9a46":[13,0,95,7],
 "structMB__MODE__INFO.html#a13f1a883e73c4b721c2212d0416b3967":[13,0,95,13],
 "structMB__MODE__INFO.html#a1570ec23444b02ce6bce496b0af637a2":[13,0,95,5],
 "structMB__MODE__INFO.html#a3643a8af086d4b016131a07878ffd88e":[13,0,95,24],
@@ -246,8 +249,5 @@ var NAVTREEINDEX7 =
 "structResizePendingParams.html#a51e85984e709e2268fc76acc7505dcd1":[13,0,118,1],
 "structRestUnitSearchInfo.html":[13,0,123],
 "structRestUnitSearchInfo.html#a3c425546935a47430e725153a839b728":[13,0,123,2],
-"structRestUnitSearchInfo.html#a5c874631576a0c407ff43677049595f9":[13,0,123,0],
-"structRestUnitSearchInfo.html#af5f8afe160f8069bab2f1d3b917a0798":[13,0,123,1],
-"structRestorationInfo.html":[13,0,119],
-"structRestorationInfo.html#a352d6b38c82cc89e1c4dcc4d6d8f07d1":[13,0,119,6]
+"structRestUnitSearchInfo.html#a5c874631576a0c407ff43677049595f9":[13,0,123,0]
 };
