@@ -72,10 +72,18 @@ var structmacroblock =
     [ "color_sensitivity_sb_g", "structmacroblock.html#aeb89ef22421a3d3ce7ee8d87222cd4ff", null ],
     [ "color_sensitivity_sb_alt", "structmacroblock.html#ab98b279dcf8ab1def1577a55f69eefe9", null ],
     [ "color_sensitivity", "structmacroblock.html#a7c1c40cf6f00bb9d84721d5789f4f22a", null ],
+    [ "min_dist_inter_uv", "structmacroblock.html#a0e5ebbd5564bfe2b6db777a6564eed68", null ],
+    [ "dqcoeff_buf", "structmacroblock.html#a4628bff3ec7fa647b930a0635845dcc5", null ],
     [ "source_variance", "structmacroblock.html#a2768397e93e4a74a5bb41380262a937f", null ],
+    [ "block_is_zero_sad", "structmacroblock.html#a147a39e4ed48ab5e0f1a8bbc72165e88", null ],
+    [ "sb_me_partition", "structmacroblock.html#ae224deb58c16db949cf65c36897cf273", null ],
+    [ "sb_me_block", "structmacroblock.html#a29c39720d5ddc64d38cd49798ff2941a", null ],
+    [ "sb_me_mv", "structmacroblock.html#a8a9879bd67940ef605eeab288e6176c5", null ],
     [ "pred_sse", "structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0", null ],
     [ "try_merge_partition", "structmacroblock.html#a41dd07e2cc09c9aefdb24018f610a20e", null ],
     [ "src_var_info_of_4x4_sub_blocks", "structmacroblock.html#ad456641e8b4e392bf16b91d7277a2936", null ],
     [ "last_set_offsets_loc", "structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed", null ],
-    [ "palette_pixels", "structmacroblock.html#adac07c2ba2d02afc50a786074d07cfea", null ]
+    [ "palette_pixels", "structmacroblock.html#adac07c2ba2d02afc50a786074d07cfea", null ],
+    [ "sb_stats_cache", "structmacroblock.html#adf69f9def7a56f79122566c3da0d7308", null ],
+    [ "sb_fp_stats", "structmacroblock.html#aa60f4777729dcb44b070647577bc5a48", null ]
 ];
\ No newline at end of file
